@@ -1,21 +1,30 @@
 package Module::Build::Platform::MacOS;
 
 use strict;
+use vars qw($VERSION);
+$VERSION = '0.30';
+$VERSION = eval $VERSION;
 use Module::Build::Base;
-use base qw(Module::Build::Base);
+use vars qw(@ISA);
+@ISA = qw(Module::Build::Base);
 
 use ExtUtils::Install;
 
+sub have_forkpipe { 0 }
+
 sub new {
   my $class = shift;
   my $self = $class->SUPER::new(@_);
   
   # $Config{sitelib} and $Config{sitearch} are, unfortunately, missing.
-  $self->{config}{sitelib}  ||= $self->{config}{installsitelib};
-  $self->{config}{sitearch} ||= $self->{config}{installsitearch};
+  foreach ('sitelib', 'sitearch') {
+    $self->config($_ => $self->config("install$_"))
+      unless $self->config($_);
+  }
   
   # For some reason $Config{startperl} is filled with a bunch of crap.
-  $self->{config}{startperl} =~ s/.*Exit \{Status\}\s//;
+  (my $sp = $self->config('startperl')) =~ s/.*Exit \{Status\}\s//;
+  $self->config(startperl => $sp);
   
   return $self;
 }
@@ -77,7 +86,7 @@ sub ACTION_install {
   return $self->SUPER::ACTION_install(@_)
     if eval {ExtUtils::Install->VERSION('1.30'); 1};
     
-  no warnings 'redefine';
+  local $^W = 0; # Avoid a 'redefine' warning
   local *ExtUtils::Install::find = sub {
     my ($code, @dirs) = @_;
 
@@ -89,8 +98,6 @@ sub ACTION_install {
   return $self->SUPER::ACTION_install(@_);
 }
 
-sub need_prelink_c { 1 }
-
 1;
 __END__
 
@@ -137,6 +144,7 @@ Need to unlock the Build program before deleting.
 
 Michael G Schwern <schwern@pobox.com>
 
+
 =head1 SEE ALSO
 
 perl(1), Module::Build(3), ExtUtils::MakeMaker(3)
