@@ -1,21 +1,18 @@
 package Module::Build::Platform::darwin;
 
 use strict;
+use vars qw($VERSION);
+$VERSION = '0.30';
+$VERSION = eval $VERSION;
 use Module::Build::Platform::Unix;
 
 use vars qw(@ISA);
 @ISA = qw(Module::Build::Platform::Unix);
 
-sub compile_c {
-  my ($self, $file) = @_;
-
-  # -flat_namespace isn't a compile flag, it's a linker flag.  But
-  # it's mistakenly in Config.pm as both.  Make the correction here.
-  local $self->{args}{ccflags} = $self->{args}{ccflags};
-  $self->{args}{ccflags} =~ s/-flat_namespace//;
-  $self->SUPER::compile_c($file);
-}
-
+# This class isn't necessary anymore, but we can't delete it, because
+# some people might still have the old copy in their @INC, containing
+# code we don't want to execute, so we have to make sure an upgrade
+# will replace it with this empty subclass.
 
 1;
 __END__
@@ -34,7 +31,7 @@ Please see the L<Module::Build> for the general docs.
 
 =head1 AUTHOR
 
-Ken Williams, ken@forum.swarthmore.edu
+Ken Williams <kwilliams@cpan.org>
 
 =head1 SEE ALSO
 
