@@ -3,17 +3,17 @@ package MBTest;
 use strict;
 
 use File::Spec;
+use File::Path ();
 
 BEGIN {
   # Make sure none of our tests load the users ~/.modulebuildrc file
   $ENV{MODULEBUILDRC} = 'NONE';
 
-  # In case the test wants to use Test::More or our other bundled
-  # modules, make sure they can be loaded.  They'll still do "use
-  # Test::More" in the test script.
+  # In case the test wants to use our other bundled
+  # modules, make sure they can be loaded.
   my $t_lib = File::Spec->catdir('t', 'bundled');
 
-  if (!$ENV{PERL_CORE}) {
+  unless ($ENV{PERL_CORE}) {
     push @INC, $t_lib; # Let user's installed version override
   } else {
     # We change directories, so expand @INC to absolute paths
@@ -34,6 +34,7 @@ BEGIN {
 use Exporter;
 use Test::More;
 use Config;
+use Cwd ();
 
 # We pass everything through to Test::More
 use vars qw($VERSION @ISA @EXPORT %EXPORT_TAGS $TODO);
@@ -44,17 +45,53 @@ $VERSION = 0.01;
 
 # We have a few extra exports, but Test::More has a special import()
 # that won't take extra additions.
-my @extra_exports = qw(stdout_of stderr_of slurp find_in_path check_compiler);
+my @extra_exports = qw(
+  stdout_of
+  stderr_of
+  stdout_stderr_of
+  slurp
+  find_in_path
+  check_compiler
+  have_module
+  ensure_blib
+);
 push @EXPORT, @extra_exports;
 __PACKAGE__->export(scalar caller, @extra_exports);
+# XXX ^-- that should really happen in import()
+########################################################################
 
+{ # Setup a temp directory if it doesn't exist
+  my $cwd = Cwd::cwd;
+  my $tmp = File::Spec->catdir( $cwd, 't', '_tmp' . $$);
+  mkdir $tmp, 0777 unless -d $tmp;
+
+  sub tmpdir { $tmp }
+  END {
+    if(-d $tmp) {
+      # Go back to where you came from!
+      chdir $cwd or die "Couldn't chdir to $cwd";
+      File::Path::rmtree($tmp) or diag "cannot clean dir '$tmp'";
+    }
+  }
+}
+########################################################################
+
+{ # backwards compatible temp filename recipe adapted from perlfaq
+  my $tmp_count = 0;
+  my $tmp_base_name = sprintf("%d-%d", $$, time());
+  sub temp_file_name {
+    sprintf("%s-%04d", $tmp_base_name, ++$tmp_count)
+  }
+}
+########################################################################
 
 sub save_handle {
   my ($handle, $subr) = @_;
-  my $outfile = 'save_out';
+  my $outfile = temp_file_name();
 
   local *SAVEOUT;
-  open SAVEOUT, ">&" . fileno($handle) or die "Can't save output handle: $!";
+  open SAVEOUT, ">&" . fileno($handle)
+    or die "Can't save output handle: $!";
   open $handle, "> $outfile" or die "Can't create $outfile: $!";
 
   eval {$subr->()};
@@ -67,6 +104,14 @@ sub save_handle {
 
 sub stdout_of { save_handle(\*STDOUT, @_) }
 sub stderr_of { save_handle(\*STDERR, @_) }
+sub stdout_stderr_of {
+  my $subr = shift;
+  my ($stdout, $stderr);
+  $stdout = stdout_of ( sub {
+      $stderr = stderr_of( $subr )
+  });
+  return ($stdout, $stderr);
+}
 
 sub slurp {
   my $fh = IO::File->new($_[0]) or die "Can't open $_[0]: $!";
@@ -74,16 +119,26 @@ sub slurp {
   return scalar <$fh>;
 }
 
+# Some extensions we should know about if we're looking for executables
+sub exe_exts {
+
+  if ($^O eq 'MSWin32') {
+    return split($Config{path_sep}, $ENV{PATHEXT} || '.com;.exe;.bat');
+  }
+  if ($^O eq 'os2') {
+    return qw(.exe .com .pl .cmd .bat .sh .ksh);
+  }
+  return;
+}
+
 sub find_in_path {
   my $thing = shift;
   
   my @path = split $Config{path_sep}, $ENV{PATH};
-  my @exe_ext = $^O eq 'MSWin32' ? ('', # may have extension already
-    split($Config{path_sep}, $ENV{PATHEXT} || '.com;.exe;.bat')) :
-    ('');
+  my @exe_ext = exe_exts();
   foreach (@path) {
     my $fullpath = File::Spec->catfile($_, $thing);
-    foreach my $ext ( @exe_ext ) {
+    foreach my $ext ( '', @exe_ext ) {
       return "$fullpath$ext" if -e "$fullpath$ext";
     }
   }
@@ -105,4 +160,21 @@ sub check_compiler {
   return ($have_c_compiler, $mb->feature('C_support'));
 }
 
+sub have_module {
+  my $module = shift;
+  return eval "use $module; 1";
+}
+
+sub ensure_blib {
+  # Make sure the given module was loaded from blib/, not the larger system
+  my $mod = shift;
+  (my $path = $mod) =~ s{::}{/}g;
+  
+ SKIP: {
+    skip "no blib in core", 1 if $ENV{PERL_CORE};
+    like $INC{"$path.pm"}, qr/\bblib\b/, "Make sure $mod was loaded from blib/";
+  }
+}
+
 1;
+# vim:ts=2:sw=2:et:sta
